package com.bwie.position.service.impl;

import com.alibaba.fastjson.JSON;
import com.bwie.common.domain.Company;
import com.bwie.common.domain.Position;
import com.bwie.common.domain.User;
import com.bwie.common.domain.WaitPerson;
import com.bwie.common.domain.request.PositionReq;
import com.bwie.common.exception.ProductException;
import com.bwie.position.mapper.PositionMapper;
import com.bwie.position.service.PositionService;
import org.joda.time.format.DateTimeFormat;
import org.springframework.amqp.rabbit.core.RabbitTemplate;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import javax.swing.text.DateFormatter;
import java.text.DateFormat;
import java.time.LocalDateTime;
import java.time.format.DateTimeFormatter;
import java.time.temporal.ChronoUnit;
import java.util.List;
import java.util.UUID;
import java.util.concurrent.TimeUnit;

import static io.lettuce.core.pubsub.PubSubOutput.Type.message;

/**
 * @Author：weiran
 * @Package：com.bwie.position.service.impl
 * @Project：week3
 * @name：PositionServiceImpl
 * @Date：2024/8/6 11:27
 */
@Service
public class PositionServiceImpl implements PositionService {
    @Autowired
    private PositionMapper positionMapper;
    @Autowired
    private RabbitTemplate rabbitTemplate;


    /**
     * 查询企业招聘列表
     * @param positionReq
     * @return
     */
    @Override
    public List<Position> findlist(PositionReq positionReq) {
        return positionMapper.findlist(positionReq);
    }


    /**
     * 查询企业列表
     * @param
     * @return
     */
    @Override
    public List<Company> findcompanylist() {
        return positionMapper.findcompanylist();
    }

    /**
     * 查询最新岗位
     * @return
     */
    @Override
    public List<Position> findlatest() {
        return positionMapper.findlatest();
    }

    @Override
    public Integer addwaitperson(WaitPerson waitPerson) {
        //如果该岗位当前登录用户已投递，则提示用户：该岗位您已投递过，请耐心等待！
        WaitPerson waitPerson1 = positionMapper.find(waitPerson);
        if (waitPerson1!=null){
            return 2;
        }

        Integer addwaitperson = positionMapper.addwaitperson(waitPerson);
        if (addwaitperson>0){
            //找到对应的用户信息个人简历表中的已投递岗位数量加一
            User user = positionMapper.finduser(waitPerson);
            positionMapper.upddelivernum(user);

            //找到对应的额企业招聘信息，更新企业招聘列表中的候选人数加一
            positionMapper.upddeliverpersonnum(waitPerson);

            return addwaitperson;

        }

        throw new ProductException("操作失败");

    }

    @Override
    public List<WaitPerson> findwaitpersonList() {
        return positionMapper.findwaitpersonList();
    }

    @Override
    public Integer passyes(WaitPerson waitPerson) {
        Integer passyes = positionMapper.passyes(waitPerson);
        if (passyes > 0) {
            //根据候选人姓名和电话号查询出候选人信息，从而获得他的email
            User user = positionMapper.finduser(waitPerson);
            user.setEmailwhat("恭喜你，你的简历已通过，请前来面试！");
            //中间件异步调用消息服务发送短信给候选人
            rabbitTemplate.convertAndSend("sendemail", JSON.toJSONString(user), message -> {
                message.getMessageProperties().setMessageId(UUID.randomUUID().toString());
                return message;
            });
            return passyes;
        }
        throw new ProductException("操作失败");
    }

    @Override
    public Integer passno(WaitPerson waitPerson) {
        Integer passno = positionMapper.passno(waitPerson);
        if (passno > 0) {
            //根据候选人姓名和电话号查询出候选人信息，从而获得他的email
            User user = positionMapper.finduser(waitPerson);
            user.setEmailwhat("很遗憾，你的简历不符合岗位要求，请再接再厉！");
            //中间件异步调用消息服务发送短信给候选人
            rabbitTemplate.convertAndSend("sendemail", JSON.toJSONString(user), message -> {
                message.getMessageProperties().setMessageId(UUID.randomUUID().toString());
                return message;
            });
            return passno;
        }
        throw new ProductException("操作失败");

    }

    @Override
    public void expire() {

        //岗位有效期为10天，使用定时任务技术或者其他的技术，定时将失效的岗位状态修改为已过期，并且列表不展示
        List<Position> list = positionMapper.findlatest();
        for (Position position : list) {
            DateTimeFormatter timeFormatter = DateTimeFormatter.ofPattern("yyyy-MM-dd HH:mm:ss");
            LocalDateTime parse = LocalDateTime.parse(position.getPublishTime(), timeFormatter);
            LocalDateTime now = LocalDateTime.now();
            long minutesBetween = ChronoUnit.DAYS.between(parse,now);
            if (minutesBetween>10){
                positionMapper.updststus(position);
            }
        }

    }


}
